@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2021-03-19 10:23:13
-:LastEditTime: 2022-02-17 10:36:11
-:LastEditors: HuangJingCan
+@LastEditTime: 2022-02-22 14:15:05
+@LastEditors: ChenCheng
 :Description: 奖品
 """
 from dataclasses import dataclass
@@ -180,6 +180,25 @@ class PrizeRosterListHandler(ClientBaseHandler):
         return self.response_json_success(page_info)
 
 
+class BackpackRedHandler(ClientBaseHandler):
+    """
+    :description: 获取用户背包红点接口（判断是否存在未下单奖品）
+    """
+    @filter_check_params("act_id,tb_user_id")
+    def get_async(self):
+        act_id = self.get_param_int("act_id")
+        user_id = self.get_param_int("tb_user_id")
+        prize_roster_ex_model = PrizeRosterExModel(context=self)
+        condition = ConditionWhere()
+        condition.add_condition("user_id=%s and act_id=%s and is_del=0 and prize_status=0")
+        params = [user_id, act_id]
+        prize_roster = prize_roster_ex_model.get_cache_dict(condition.to_string(),params=params)
+        if prize_roster:
+            return self.response_json_success(1)
+        else:
+            return self.response_json_success(0)
+            
+
 class UserPrizeListHandler(ClientBaseHandler):
     """
     :description: 获取用户奖品列表(背包)
