@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 13:44:17
-:LastEditTime: 2022-02-17 11:30:50
-:LastEditors: HuangJingCan
+@LastEditTime: 2022-02-22 14:16:43
+@LastEditors: ChenCheng
 :description: 奖品相关（包含箱数相关）接口
 """
 from copy import deepcopy
@@ -298,11 +298,10 @@ class PrizeListHandler(ClientBaseHandler):
         # 计算奖品页总体数据
         prize_all_count = act_prize_ex_model.get_total("module_id=%s and is_del=0", params=module_id)
         prize_surplus_count = act_prize_ex_model.get_total("module_id=%s and is_del=0 and is_release=1 and yfs_type=1 and surplus<=0", params=module_id)
-        # prize_lottery_count = act_prize_ex_model.get_total("module_id=%s and is_del=0 and is_release=1 and yfs_type=1 and surplus>0 and probability>0", params=module_id)
         field = "CAST(SUM(probability) AS SIGNED) AS prize_sum_probability,CAST(SUM(surplus) AS SIGNED) AS prize_surplus_sum, CAST(SUM(yfs_type) AS SIGNED) AS prize_lottery_count"
         prize_sum_probability_dict = act_prize_ex_model.get_dict("module_id=%s and is_del=0 and is_release=1 and yfs_type=1 and surplus>0 and probability>0", field=field, params=module_id)
         prize_sum_probability = prize_sum_probability_dict["prize_sum_probability"] if prize_sum_probability_dict["prize_sum_probability"] else 0
-        prize_surplus_sum = prize_sum_probability_dict["prize_surplus_sum"] if prize_sum_probability_dict["prize_surplus_sum"] else 0
+        # prize_surplus_sum = prize_sum_probability_dict["prize_surplus_sum"] if prize_sum_probability_dict["prize_surplus_sum"] else 0
         prize_lottery_count = prize_sum_probability_dict["prize_lottery_count"] if prize_sum_probability_dict["prize_lottery_count"] else 0
 
         # 获取奖品列表
@@ -312,47 +311,135 @@ class PrizeListHandler(ClientBaseHandler):
             #获取活动奖品高级配置列表
             act_prize_senior_config_list = act_prize_senior_config_model.get_dict_list("act_id=%s and module_id=%s", params=[act_id, module_id])
             for act_prize in act_prize_list:
-                act_prize["chance"] = 0
-                act_prize["status"] = 1
-                act_prize["status_name"] = "可被抽中"
+                act_prize["chance"] = 0 # 概率
+                act_prize["status"] = 0 # 奖池状态标识
+                act_prize["status_name"] = "不可被抽中"  # 奖池状态说明
+                act_prize["buy_back_status_name"] = f"{act_prize['buy_back_integral']}积分" if act_prize["is_open_buy_back"] else "未开启"  # 奖品回购状态说明
+
                 if act_prize["prize_detail_json"]:
                     act_prize["prize_detail_json"] = self.json_loads(act_prize["prize_detail_json"])
                 if act_prize["senior_ability_config"]:
                     act_prize["senior_ability_config"] = self.json_loads(act_prize["senior_ability_config"])
-                if prize_sum_probability and act_prize["is_release"] and act_prize["yfs_type"] == 1 and act_prize["probability"] > 0 and act_prize["surplus"] > 0:
-                    act_prize["chance"] = round(act_prize["probability"] / prize_sum_probability * 100, 2)
-                    if act_prize["is_senior_ability"]:
-                        senior_ability_config_list = act_prize["senior_ability_config"]
-                        if senior_ability_config_list:
-                            for senior_ability_config in senior_ability_config_list:
-                                if int(senior_ability_config["is_open"]) == 1:
-                                    if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.奖品锁定.value:
-                                        act_prize["status_name"] = f"剩余{senior_ability_config['lock_count']}时库存锁定，总库存最后{senior_ability_config['unlock_count'] }件解锁库存"
-                                        # 锁定且未到解锁时机-不可抽出
-                                        if act_prize["surplus"] <= senior_ability_config["lock_count"] and senior_ability_config["unlock_count"] < prize_surplus_sum:
-                                            act_prize["status"] = 0
-                                            act_prize["status_name"] = f"不可抽中，{prize_surplus_sum-senior_ability_config['unlock_count']}件后解锁"
-                                            break
-                                    if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.强制出奖.value:
-                                        act_prize_senior_config = [act_prize_senior_config for act_prize_senior_config in act_prize_senior_config_list if act_prize_senior_config["prize_id"] == act_prize["id"]]
-                                        if act_prize_senior_config:
-                                            act_prize_senior_config = act_prize_senior_config[0]
-                                            if act_prize_senior_config["is_lock"] == 1:
-                                                act_prize["status"] = 0
-                                                act_prize["status_name"] = f"{act_prize_senior_config['must_surplus_count']}件后可抽中"
-                                            else:
-                                                act_prize["status"] = 1
-                                                act_prize["status_name"] = f"{act_prize_senior_config['must_surplus_count']}件内必出一件"
-                                            break
-                                        else:
-                                            act_prize["status"] = 0
-                                            act_prize["status_name"] = "高级功能配置错误，请重新配置"
-                        else:
+                if act_prize["is_release"]:
+                    if act_prize["yfs_type"] == 1:
+                        if act_prize["probability"] > 0 and act_prize["surplus"] > 0:
+                            act_prize["chance"] = round(act_prize["probability"] / prize_sum_probability * 100, 2)
+                            if act_prize["is_senior_ability"]:
+                                act_prize["status"] = 0
+                                act_prize["status_name"] = "高级功能配置错误，请重新配置"
+                                senior_ability_config_list = act_prize["senior_ability_config"]
+                                if senior_ability_config_list:
+                                    for senior_ability_config in senior_ability_config_list:
+                                        if int(senior_ability_config["is_open"]) == 1:
+                                            if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.奖品锁定.value:
+                                                # act_prize["status_name"] = f"剩余{senior_ability_config['lock_count']}时库存锁定，总库存最后{senior_ability_config['unlock_count'] }件解锁库存"
+                                                # 锁定且未到解锁时机-不可抽出
+                                                if act_prize["surplus"] <= senior_ability_config["lock_count"] and senior_ability_config["unlock_count"] < prize_surplus_sum:
+                                                    act_prize["status"] = 0
+                                                    act_prize["status_name"] = f"不可抽中:{prize_surplus_sum-senior_ability_config['unlock_count']}件后解锁（奖池剩余≤{senior_ability_config['unlock_count']}件）"
+                                                else:
+                                                    act_prize["status"] = 1
+                                                    act_prize["status_name"] = f"锁定：当前奖品≤{senior_ability_config['lock_count']}件;解锁：总奖池≤{senior_ability_config['unlock_count']}件"
+                                            elif int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.强制出奖.value:
+                                                act_prize_senior_config = [act_prize_senior_config for act_prize_senior_config in act_prize_senior_config_list if act_prize_senior_config["prize_id"] == act_prize["id"]]
+                                                if act_prize_senior_config:
+                                                    act_prize_senior_config = act_prize_senior_config[0]
+                                                    if act_prize_senior_config["is_lock"] == 1:
+                                                        act_prize["status"] = 0
+                                                        act_prize["status_name"] = f"不可抽中：{act_prize_senior_config['must_surplus_count']}件后可抽中（每{senior_ability_config['lock_count']}件出一件）"
+                                                    else:
+                                                        act_prize["status"] = 1
+                                                        act_prize["status_name"] = f"{act_prize_senior_config['must_surplus_count']}件内必出一件"
+                            else:
+                                act_prize["status"] = 1
+                                act_prize["status_name"] = "可被抽中"
+                    else:
+                        if act_prize["hand_out"] > 0:
                             act_prize["status"] = 0
-                            act_prize["status_name"] = "高级功能配置错误，请重新配置"
-                else:
-                    act_prize["status"] = 0
-                    act_prize["status_name"] = "不可抽中"
+                            act_prize["status_name"] = "已自动出奖"
+                        else:
+                            if act_prize["yfs_type"] == 3:
+                                act_prize["status"] = 1
+                                act_prize["status_name"] = f"阶段{ act_prize['dd_open_step']}解锁：已出奖品≥{ act_prize['dd_open_threshold']}件"
+                            else:
+                                act_prize["status"] = 1
+                                act_prize["status_name"] = "等待自动出奖"
+
+
+
+                # 由于反复横跳的策划，可能会在某个版本回归本段判断，故而保留
+                # act_prize["status"] = 0 # 奖池状态标识
+                # act_prize["status_name"] = "不可抽中" # 奖池状态说明
+                # act_prize["must_status_name"] = "" # 强制概率状态说明
+                # act_prize["surplus_lock_status_name"] = "" # 库存锁定状态说明
+                # act_prize["special_DD_status_name"] = "" # 叠叠乐状态说明
+                # if act_prize["is_release"]:
+                #     if act_prize["yfs_type"] == 1 and act_prize["probability"] > 0 and act_prize["surplus"] > 0:
+                #         act_prize["chance"] = round(act_prize["probability"] / prize_sum_probability * 100, 2)
+                #         act_prize["status"] = 1
+                #         act_prize["status_name"] = "可被抽中"
+                #     elif act_prize["surplus"] > 0:
+                #         act_prize["status"] = 2
+                #         act_prize["status_name"] = "等待自动出奖"
+                #     else:
+                #         act_prize["status"] = 3
+                #         act_prize["status_name"] = "已自动出奖"
+
+                # if act_prize["yfs_type"] == 1:
+                # if act_prize["is_senior_ability"]:
+                #     senior_ability_config_list = act_prize["senior_ability_config"]
+                #     if senior_ability_config_list:
+                #         for senior_ability_config in senior_ability_config_list:
+                #             if int(senior_ability_config["is_open"]) == 1:
+                #                 if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.奖品锁定.value:
+                #                     act_prize["surplus_lock_status_name"] = f"锁定：当前奖品≤{senior_ability_config['lock_count']}件;解锁：总奖池≤{senior_ability_config['unlock_count']}件"
+                #                 if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.强制出奖.value:
+                #                     act_prize["must_status_name"] = f"每{senior_ability_config['lock_count']}件出一件"
+                #     else:
+                #         act_prize["must_status_name"] = "高级功能配置错误，请重新配置"
+                #         act_prize["surplus_lock_status_name"] = "高级功能配置错误，请重新配置"
+                # else:
+                #     act_prize["must_status_name"] = "未开启"
+                #     act_prize["surplus_lock_status_name"] = "未开启"
+                # elif act_prize["yfs_type"] == 3:
+                #     act_prize["special_DD_status_name"] = f"阶段{ act_prize['dd_open_step']}解锁：已出奖品≥{ act_prize['dd_open_threshold']}件"
+
+                # if prize_sum_probability and act_prize["is_release"] and act_prize["yfs_type"] == 1 and act_prize["probability"] > 0 and act_prize["surplus"] > 0:
+                #     act_prize["chance"] = round(act_prize["probability"] / prize_sum_probability * 100, 2)
+                #     if act_prize["is_senior_ability"]:
+                #         senior_ability_config_list = act_prize["senior_ability_config"]
+                #         if senior_ability_config_list:
+                #             for senior_ability_config in senior_ability_config_list:
+                #                 if int(senior_ability_config["is_open"]) == 1:
+                #                     if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.奖品锁定.value:
+                #                         act_prize["status_name"] = f"剩余{senior_ability_config['lock_count']}时库存锁定，总库存最后{senior_ability_config['unlock_count'] }件解锁库存"
+                #                         # 锁定且未到解锁时机-不可抽出
+                #                         if act_prize["surplus"] <= senior_ability_config["lock_count"] and senior_ability_config["unlock_count"] < prize_surplus_sum:
+                #                             act_prize["status"] = 0
+                #                             act_prize["status_name"] = f"不可抽中，{prize_surplus_sum-senior_ability_config['unlock_count']}件后解锁"
+                #                             break
+                #                     if int(senior_ability_config["type_id"]) == PrizeSeniorConfigType.强制出奖.value:
+                #                         act_prize_senior_config = [act_prize_senior_config for act_prize_senior_config in act_prize_senior_config_list if act_prize_senior_config["prize_id"] == act_prize["id"]]
+                #                         if act_prize_senior_config:
+                #                             act_prize_senior_config = act_prize_senior_config[0]
+                #                             if act_prize_senior_config["is_lock"] == 1:
+                #                                 act_prize["status"] = 0
+                #                                 act_prize["status_name"] = f"{act_prize_senior_config['must_surplus_count']}件后可抽中"
+                #                             else:
+                #                                 act_prize["status"] = 1
+                #                                 act_prize["status_name"] = f"{act_prize_senior_config['must_surplus_count']}件内必出一件"
+                #                             break
+                #                         else:
+                #                             act_prize["status"] = 0
+                #                             act_prize["status_name"] = "高级功能配置错误，请重新配置"
+                #         else:
+                #             act_prize["status"] = 0
+                #             act_prize["status_name"] = "高级功能配置错误，请重新配置"
+                # else:
+                #     act_prize["status"] = 0
+                #     act_prize["status_name"] = "不可抽中"
+
+
 
         page_info = PageInfo(page_index, page_size, total, act_prize_list)
         page_info.prize_all_count = prize_all_count
