@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2022-02-17 11:13:49
-:LastEditTime: 2022-02-17 11:14:21
-:LastEditors: HuangJingCan
+@LastEditTime: 2022-02-22 14:14:25
+@LastEditors: ChenCheng
 :Description: 扭蛋机一番赏基础路由
 """
 # 框架引用
@@ -124,6 +124,7 @@ def seven_cloudapp_ndjyfs_route():
         (r"/client/special_prize_notice", prize.SpecialPrizeNoticeHandler),  # 特殊奖品发放通知
         (r"/client/update_special_prize_notice", prize.UpdateSpecialPrizeNoticeHandler),  # 更新特殊奖品发放通知
         (r"/client/user_prize_list", prize.UserPrizeListHandler),  # 获取用户奖品列表(背包)  --  包含已下单和可回购列表
+        (r"/client/backpack_red", prize.BackpackRedHandler),  #获取用户背包红点接口（判断是否存在未下单奖品）
         (r"/client/prize_order_list", prize.PrizeOrderHandler),  #获取奖品订单列表
         (r"/client/buy_back_prize", prize.BuyBackPrizeHandler),  # 奖品主动回购获得积分
         (r"/client/choice_prize_sku", prize.ChoicePrizeSkuHandler),  #选择奖品sku
